R/plots.R
ggvar.RdThis function displays a graphical representation of the variables (columns) of a multivariate analysis.
This function displays a graphical representation of the variables
(columns) of a multiple correspondence analysis generated by the MCA
function of the FactoMineR package.
ggvar(obj, ...)
# S3 method for class 'MCA'
ggvar(obj, xax = 1, yax = 2, size = 4, alpha = 0.5, palette = "Set1", ...)